Contact Us | Brookdale Community CollegeBrookdale Community College
Description: Before you hit the form below, is your question answered here?

MyBrookdale

# Contact Us

#### Before you hit the form below, is your question answered here?

## Contact Us FAQ

### I’m interested in applying to Brookdale (first-time applicants).

To start the process you will need to submit the Brookdale application, which you can complete online at http://www.brookdalecc.edu/admissions/apply-online

Next: if you have not previously attended any college then you will need to take our Basic Skills Placement Exam (Accuplacer) after you have submitted your application. You can take the exam on a walk-in basis in our Testing Center; location and hours here.

Third: after taking the Accuplacer Basic Skills exam, you’ll schedule an appointment with a Counselor (academic advisor) to review your Accuplacer results and for assistance with registering for courses.

### I want to transfer into Brookdale.

Brookdale evaluates and transfers credits from a variety of sources. When transferring into Brookdale, you may transfer up to half your degree credits from outside sources. Credit can be granted only for work completed at accredited colleges. A good place to start is here.

Credits may be used to satisfy general education coursework for your degree, or to satisfy some of the career studies coursework. At least half your career studies coursework must be completed here at Brookdale.

Transfer credit may be granted for classes from 100- and 200- level coursework; but Basic Skills coursework (also known as remedial or developmental coursework) is not transferable. Upper level coursework (300, 400, graduate, and above) is evaluated on an individual basis.

You must have earned a grade of C or higher in your previous coursework for it to be considered for transfer. (The grade point average, however, will not be transferred into Brookdale.)

In order to transfer into Brookdale you will need to submit an application; you can apply online at http://www.brookdalecc.edu/admissions/apply-online/

Once you have applied, please have your official transcript(s) from prior college(s) sent to Brookdale. To verify that your official transcript has been received, please contact Recruitment Services at 732-224-1857 or e-mail recruitment@brookdalecc.edu

Lastly, you will then need to schedule an appointment with a counselor to go over your credits and evaluate which ones will transfer.

### I’m enrolled at another college and want to attend Brookdale as a “visiting student.”

To start, you will need to submit the Brookdale application, which you can do online at http://www.brookdalecc.edu/admissions/apply-online/

As a visiting student you are not required to submit a letter from your home institution giving you permission to take courses at Brookdale (unless you are registering for developmental “zero level” courses; if this is the case, you must submit a letter from your home institution giving you permission to take that specific “zero level” course at Brookdale, or you can make an appointment with a Brookdale counselor for approval to register in that “zero level” course.)

Search for classes via Webadvisor. Using the drop down menus, select your term, course name, and course number (optional) – then hit submit. Results show the dates, times, open/closed status for the course you’re interested in, along with instructor name, syllabi, and textbook information.

As a visiting student, it is your responsibility to verify that the course(s) you are taking at Brookdale will transfer to your home institution, and that you have the prerequisites necessary to succeed in the course(s). It is very important that you meet with your home institution advisor and review the Brookdale course descriptions. This will ensure that what you take here meets your requirements and will transfer back.

More information about visiting students here: http://www.brookdalecc.edu/admissions/visiting-students/

### Does Brookdale offer the course I want?

To view available classes visit Webadvisor. Select the appropriate term from the TERM drop down menu; then select the course name from the SUBJECT drop down menu. Select the course number (this can be left empty if you’re unsure) from the COURSE NUMBER drop down menu. Then click SUBMIT.

Your results will show the dates and times, and open/closed (seats still available) status, for each individual course along with the syllabi, instructor name and textbook information.

### Where is the Brookdale catalog?

Like most colleges and universities, Brookdale no longer prints a catalog: all our courses are in a database available via Acalog.

Acalog is also where you will find deep, updated information about academic programs and certificates, specific enrollment requirements, academic policies, the grading system, graduation requirements – in short, everything that was included in the original hard copy catalog.

### I’m interested in non-credit professional / career training.

Professional training classes are offered by the Office of Business and Community Development – visit them online at http://continuinged.brookdalecc.edu/

They also offer our Summer Camps, Trips and Tours, Personal Development classes and much more. E-mail bcd@brookdalecc.edu or phone 732-224-2315.

### Where can I learn about online classes?

Brookdale students may take online courses in addition to more traditional face-to-face courses, or earn a degree entirely online. Learn more about online classes.

### Can I earn a Bachelor’s or Master’s degree at Brookdale?

The New Jersey Coastal Communiversity, led by Brookdale, is an alliance of New Jersey colleges and universities who are jointly offering selected Associate, Bachelor’s, and Master’s degrees (and graduate certificates) right here in Monmouth County.

Our partners are Rutgers University, Montclair State University, Georgian Court University, New Jersey City University, and New Jersey Institute of Technology. Degree programs in a variety of majors include Business, Education, Public Safety, Social Work, Information Technology, Liberal Arts and Nursing.

For more information, visit http://www.brookdalecc.edu/academics/nj-coastal-communiversity/ or contact the Communiversity at info@njcommuniversity.org

### I’m interested in a campus tour.

Recruitment Services offers visits and tours of campus Monday-Friday. To schedule a tour, please contact Recruitment at 732-224-1857 or e-mail recruitment@brookdalecc.edu

### How can I contact the Campus Police?

The Brookdale police are on campus 24 hours a day, 365 days a year. They have the same training and authority as any New Jersey municipal police officer with full arrest powers; they enforce both traffic and criminal statutes as well as College policies and regulations.

On-Campus Phone
In an emergency, dial 911 or 2222 from any on-campus phone. For non-emergencies dial 2352.

Off-Campus Phones
Dial (732) 842-1950 in an emergency. For non-emergencies, (732) 224-2352.

Emergency Phones around Campus
There are 22 yellow emergency phones identified by blue lights located throughout the campus. Open the door of the phone box, pick up the handset and the Police will be contacted whether or not a message is transmitted. View a high resolution map showing emergency phone locations.

### How can I find a specific (main campus) classroom / event location?

If you know your intended location, find it on the high resolution campus map (with locations key on the right). If you are coming to the main campus for a special event, check your event’s Calendar listing for specifics and accompanying map.

Students, if you don’t know your classroom location, check your schedule in the MyBrookdale Portal.

### I’m a U.S. Armed Services Veteran.

The Veterans Affairs office in Admissions, Records & Registration helps all veterans and eligible dependents make full use of their V.A. Educational Entitlements under the Montgomery G.I. Bill, National Guard Tuition Waiver, VA Vocational Rehabilitation, VEAP/REAP and VRAP programs.

Information and referral to other veterans’ benefits is available, as is information on the New Jersey Tuition Assistance Program for eligible veterans. Visit Veteran’s Affairs.

### I am not a US citizen.

Each term, our International Education Center works with over 100 international students, from about 45 countries, who have F-1 student visas. Visit the International Education Center’s website for information for both prospective and current students as well as a list of helpful links for all students.

### I’d like to find out about Disability Services.

At Brookdale there are many students with disabilities; the College offers individualized and reasonable accommodations and/or services to qualified persons with disabilities, to ensure complete access and full participation in the educational process.

Read the FAQ developed by Disability Services or contact Ernest Oversen, Director, at 732-224-2729 or by e-mail to eoversen@brookdalecc.edu

### I need a Transcript (or Verification of Enrollment, Signature Page).

Official transcripts of your grades are available through the Office of Admissions, Records and Registration.

Regulations for obtaining official transcripts require you to either apply in person at the main campus or at one of our regional locations, or send us a written mailed request.

There is a request form here that you can pre-fill; bring or mail the form along with your $3 fee (per copy) via check or money order made out to Brookdale Community College.

Please keep in mind that transcripts typically take 7-10 business days to process during non-peak periods, and during peak registration (January and August, for example) you should anticipate a processing time of approximately 2-3 weeks.

Transcript requests must be made by the student and can not be accepted on behalf of the student from other individuals.

For all other documents - Immunization Form, Signature Page, Enrollment Verification, Change of Residency – please visit http://www.brookdalecc.edu/admissions/admissions/forms/

Questions? Contact the Office of Admissions, Records, and Registration at 732-224-2375 or at records@brookdalecc.edu

### I need IT help: Canvas / MyBrookdale Portal

All technology issues are handled by the OIT Help Desk at (732) 224-2829 or by e-mail to helpdesk@brookdalecc.edu

Visit the Office of Information Technology online to see if your question is addressed in OIT support materials and online resources.

### I have a question about my tuition bill / financial aid.

Start by reading the Tuition FAQs here. If you need help with your financial aid award, visit the Financial Aid website for information and contact details. Finally, contact the Accounts Receivable department at 732-224-2256 or by e-mail to mdestefano@brookdalecc.edu

### I’m interested in chargeback for Out-of-County students.

Out-of-county residents who attend Brookdale because their county does not have a community college, or because their county’s community college does not offer the program they wish to pursue, may be eligible for full or partial chargeback, a system by which they pay in-county tuition rates.

In order to be eligible for a chargeback, you must first register for courses at Brookdale. When you register, be sure to request a Chargeback Form from Admissions, Records, and Registration.

Then, take the form to your local community college for approval. If you are pursuing a program that they do not offer, they should approve the chargeback.

Bring the completed form back to Brookdale Registration so your tuition can be adjusted to reflect the Monmouth County resident rate.

### What are the key dates (Add, Drop, Late, Refunds, etc.) for the current term?

Visit the Important Term Dates page for links to current and forthcoming terms -these will contain all the important financial, registration, add/drop dates and more.

### Where is the Testing Center?

The Testing Center is located on the lower level of the CAR Building (Center for Counseling, Admissions & Registration) on the Lincroft campus – use parking lot 4.

The Accuplacer Test (Basic Skills for new applicants) is also available at Brookdale’s regional locations by appointment. Visit the Testing Center online.

### Where and how do I buy my textbooks?

You can buy your textbooks in person at the Scroll and Pen Bookstore in the Warner Student Life Center on the Lincroft Campus, or buy them online. For complete information and links, please visit the Scroll & Pen website or call (732) 224-2382.

### How do I contact my counselor?

The Counseling and Advising Department can be reached at 732-224-2555. For more information about the hours of operations or to schedule an appointment, please visit Counseling and Advising online.

### How do I contact my professor?

Use the Employee Directory to find everyone who works at Brookdale.

### Useful Sites and Phone Numbers

Admissions & Registration (732) 224-2944

http://www.brookdalecc.edu/admissions/admissions/
http://www.brookdalecc.edu/admissions/registration/

Financial Aid (732) 224-2361
http://www.brookdalecc.edu/admissions/financial-aid/

Veterans Services (732) 224-2273
http://www.brookdalecc.edu/admissions/admissions/veterans-services/

Testing Services (732) 224-2584
http://www.brookdalecc.edu/academics/testing-services/

Student Life & Activities (732) 224-2788
http://www.brookdalecc.edu/campus-life/student-life-activities/

Accounts Receivable
http://www.brookdalecc.edu/services/admin-offices/finance-operations/accounts-receivable/

Accounting – Gen. Information (732) 224-2707
Accounting – Payments (732) 224-2707
Accounting – Credit Card Payments (732) 224-2125

Bankier Library (732) 224-2706
http://ux.brookdalecc.edu/library/index.php

Scroll & Pen BookStore – Textbooks (732) 2382 / General Information (732) 224-2595
http://www.brookdalecc.edu/services/admin-offices/bookstore/

Disability Services – TTY – (732) 842-4211
http://www.brookdalecc.edu/services/admin-offices/disability-services/

Eastern Monmouth Higher Education Center in Neptune (732) 774-3363
http://www.brookdalecc.edu/about/regional-locations/brookdale-at-neptune/

Northern Monmouth Higher Education Center in Hazlet (732) 739-6010
http://www.brookdalecc.edu/about/regional-locations/brookdale-at-hazlet/

Long Branch Center (732) 229-8440
http://www.brookdalecc.edu/about/regional-locations/brookdale-at-long-branch/

Wall Higher Ed Center/Communiversity 732-280-7090
http://www.brookdalecc.edu/about/regional-locations/brookdale-at-wall/

Western Monmouth (Freehold) Center (732) 780-0020
http://www.brookdalecc.edu/about/regional-locations/brookdale-at-freehold/

### Contact Us

We look forward to hearing from you. Please complete the form and we will be in touch with you shortly.

- Name*
- Best contact type
- Best time for phone call
  - In the morning
  - In the afternoon
  - In the evening
- Phone*
- Email*
- My Question Concerns:
  - General Information
  - Applying/Registering
  - Financial Aid/Scholarships
  - Specific Program/Course Offering
  - NonCredit Classes/Community Events
  - International Students
  - Human Resources
- Question or Comment